package screenpager::Config;
#
# configuration file for screenpager
#
# SYNOPSIS
# --------
# use lib "$ENV{HOME}/.config", '/etc/xdg'; # for loading config files, more or less per http://www.freedesktop.org/Standards/basedir-spec
# require screenpager::Config;
# my $screen_count = scalar @screenpager::Config::screen;
# my $display_font = $screenpager::Config::display{font};
#
# DESCRIPTION
# -----------
# *screenpager* looks for its configuration file
# first in $HOME/.config/screenpager/
# then in /etc/xdg/screenpager/
#
# Details of format follow:
#
use strict; use warnings;


    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    # Validation.
    # Set this to 1 if all configuration items are valid.
    # The default of 0 disables screenpager.
    #
    my $valid = 0;



    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    # Layout and resolution of screens.
    # The west (left-most) screen is listed first.
    # Add or remove entries to match the actual number of screens in use.
    #
    our @screen =
    (
        {
            width => 1024, # pixels
            height => 768,
        },
        {
            width => 1280,
            height => 1024,
        },
        {
            width => 1280,
            height => 1024,
        },
        {
            width => 1024,
            height => 768,
        },
        {
            width => 1280,
            height => 1024,
        },
    );



    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    # Desktop for holding swapped-out windows.
    # Create the desktop with your window manager,
    # and record its number here.
    # Desktops are numbered from zero.
    #
    our $swap_desktop = 2;



    # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    # Appearance and behaviour of on-screen display.
    #
    our %display =
    (
      # font => '-monotype-arial black-medium-r-normal--*-400-*-*-p-*-iso8859-1',
      # font => '-monotype-impact-medium-r-condensed--*-340-*-*-p-*-iso8859-1',
      # font => '-b&h-luxi sans-bold-r-normal--*-340-*-*-p-*-iso8859-1',
        font => '12x24',
        fill_colour => '#DD9', # of glyph interiors
        outline_colour => 'black', # of glyph outlines
        outline_thickness => 2, # pixels
        duration => 4, # seconds # default for "display on"
    );



##### I m p l e m e n t a t i o n ########################################################


    $valid or die 'screenpager: invalid configuration in ' . __FILE__ . "\n";



1;
